=== modified file 'libssts/Callback.h'
--- libssts/Callback.h	2015-11-14 17:26:42 +0000
+++ libssts/Callback.h	2016-01-25 21:52:28 +0000
@@ -35,7 +35,7 @@
 /**
  * A list containing the names of the callback types.
  */
-UNUSED
+S_UNUSED
 static char *
 SCallbackTypeNames[] = {
   "NULL",

=== modified file 'libssts/DynamicArray.c'
--- libssts/DynamicArray.c	2015-10-28 14:45:22 +0000
+++ libssts/DynamicArray.c	2016-01-25 21:52:28 +0000
@@ -42,7 +42,7 @@
                              spointer data);
 
 SDynamicArray *
-_s_dynamic_array_new_full (size_t len,
+s_dynamic_array_new_full (size_t len,
                           FreeFunc free_func,
                           FuncPointer to_json,
                           FuncPointer from_json) {
@@ -70,7 +70,7 @@
 s_dynamic_array_new (size_t len,
                      FreeFunc free_func) {
 
-  SDynamicArray * self = _s_dynamic_array_new_full (len, free_func, NULL, NULL);
+  SDynamicArray * self = s_dynamic_array_new_full (len, free_func, NULL, NULL);
 
   return self;
 }
@@ -80,7 +80,7 @@
                           FreeFunc free_func,
                           FuncPointer to_json,
                           FuncPointer from_json) {
-  SDynamicArray * self = _s_dynamic_array_new_full (len, free_func, to_json, from_json);
+  SDynamicArray * self = s_dynamic_array_new_full (len, free_func, to_json, from_json);
   return self;
 }
 

=== modified file 'libssts/DynamicArray.h'
--- libssts/DynamicArray.h	2015-11-14 17:14:26 +0000
+++ libssts/DynamicArray.h	2016-01-25 21:52:28 +0000
@@ -74,6 +74,12 @@
 s_dynamic_array_new (size_t len,
                      FreeFunc free_func);
 
+SDynamicArray *
+s_dynamic_array_new_full (size_t len,
+                          FreeFunc free_func,
+                          FuncPointer to_json,
+                          FuncPointer from_json);
+
 /**
  * Same as s_dynamic_array_new() but with support for to_json and from_json
  * methods.

=== modified file 'libssts/Error.c'
--- libssts/Error.c	2015-10-26 22:04:15 +0000
+++ libssts/Error.c	2016-01-25 21:52:28 +0000
@@ -152,7 +152,7 @@
   if (_internal_s_error_domain_list) {
     s_dynamic_array_free (_internal_s_error_domain_list, TRUE);
   }
-  s_dbg_print ("Done taring down error system.");
+  s_dbg_print ("Done tearing down error system.");
 }
 
 
@@ -171,7 +171,7 @@
   }
 
   if (!(_internal_s_error_domain_list)) {
-    s_dbg_print ("Array does not exist, lets crete it!");
+    s_dbg_print ("Array does not exist, lets create it!");
     _internal_s_error_domain_list =
           s_dynamic_array_new (S_ERROR_DOMAIN_RANGE_MAX,
           FREEFUNC (_internal_s_error_domain_item_free));

=== modified file 'libssts/LinkedList.c'
--- libssts/LinkedList.c	2015-11-14 17:25:14 +0000
+++ libssts/LinkedList.c	2016-01-25 21:52:28 +0000
@@ -74,24 +74,30 @@
                             FOREACHFUNC (_internal_s_liked_list_free_item),
                             NULL);
   }
-  /* Now the "snake" will "eat" its own tail. :-)
-   * Based on this: http://stackoverflow.com/a/7025370
+  /*if we have a current item we free the list, if not, we do nothing.
    */
-  SLinkedListNode * tmp;
-  SLinkedListNode * itm = self->head;
-  do{
-    tmp = itm;
-    itm = itm->next;
-    free (tmp);
-  } while (itm != NULL);
-  self->head = NULL;
+  if (self->current) {
+    /* Now the "snake" will "eat" its own tail. :-)
+     * Based on this: http://stackoverflow.com/a/7025370
+     */
+    SLinkedListNode * tmp;
+    SLinkedListNode * itm = self->head;
+    do{
+      tmp = itm;
+      itm = itm->next;
+      free (tmp);
+    } while (itm != NULL);
+    self->head = NULL;
+  }
   free (self);
 }
 
 void
 internal_s_linked_list_initialize_first_item (SLinkedList * self) {
   assert (self->len == 0);
-  assert (self->head == NULL && self->tail == NULL && self->current == NULL);
+  assert (self->head == NULL);
+  assert (self->tail == NULL);
+  assert (self->current == NULL);
   self->current = malloc (sizeof (SLinkedListNode));
   self->head = self->current;
   self->tail = self->current;
@@ -235,6 +241,12 @@
   SLinkedListNode * next = self->current->next;
   SLinkedListNode * current = self->current;
 
+  
+  if (!s_linked_list_get_current (self)) {
+    s_err_print ("The \"current\" item does not exist. ");
+    return;
+  }
+  
   if (free_data) {
     FreeFunc free_func = self->free_func;
     spointer data = current->data;
@@ -244,14 +256,36 @@
       free (data);
     }
   }
-
-  self->current = prev;
-
-  prev->next = next;
-  next->prev = prev;
-
+  
+  
+
+  if (prev) {
+    prev->next = next;
+  }
+  if (next) {
+    next->prev = prev;
+  }
+  
+  /*
+   * Don't.. Just don't sak.. This is the best I could do...
+   * Replace it if you can come up with a better way of doing this.
+   */
+  if (current == self->tail) {
+    self->current = self->tail->prev;
+    self->tail = self->current;
+  } 
+  if (current == self->head) {
+    self->current = self->head->next;
+    self->head = self->current;
+  } 
+  if (!(current == self->head) && !(current == self->tail)) {
+    self->current = prev;
+  }
+  
   free (current);
-
+  current = NULL;
+  
+  
   self->len--;
 }
 

=== modified file 'libssts/Map.c'
--- libssts/Map.c	2015-11-14 17:25:14 +0000
+++ libssts/Map.c	2016-01-25 21:52:28 +0000
@@ -94,7 +94,13 @@
    */
   self->free_key = free_key;
   self->free_value = free_value;
-
+  
+  /*
+   * Creating a place to store the items.
+   */
+  self->array = s_dynamic_array_new (S_MAP_DEFAULT_NUMBER_OF_BUCKETS,
+                                     FREEFUNC (s_map_item_free));
+  
   /* if no func is set we have to use some other metod of
    */
   if (key_hash_func == NULL){
@@ -103,20 +109,17 @@
     self->key_hash_func = key_hash_func;
   }
 
-  self->array = s_dynamic_array_new (S_MAP_DEFAULT_NUMBER_OF_BUCKETS,
-                                     FREEFUNC(_internal_s_map_free_buckets));
-
   return self;
 }
 
 void
 s_map_free (SMap * self, sboolean free_data) {
-
+  
   s_map_for_each (self,
                   FOREACHFUNC(_s_map_internal_free_map_items_for_each),
-                  &free_data);
+                  free_data);
 
-  s_dynamic_array_free (self->array, TRUE);
+  s_dynamic_array_free (self->array, FALSE);
   free (self);
 }
 
@@ -254,8 +257,3 @@
   }
 }
 
-void
-_internal_s_map_free_buckets (SLinkedList * self) {
-  s_dbg_print ("Freeing bucket.");
-  s_linked_list_free (self, FALSE);
-}

=== modified file 'libssts/SimpleTypeSystem.h'
--- libssts/SimpleTypeSystem.h	2015-11-14 17:14:26 +0000
+++ libssts/SimpleTypeSystem.h	2016-01-25 21:52:28 +0000
@@ -48,6 +48,7 @@
 #include "Callback.h"
 #include "defs.h"
 #include "DynamicArray.h"
+#include "LinkedList.h"
 #include "Error.h"
 #include "Func.h"
 #include "hash.h"

=== modified file 'tests/CMakeLists.txt'
--- tests/CMakeLists.txt	2015-10-28 14:45:22 +0000
+++ tests/CMakeLists.txt	2016-01-25 21:52:28 +0000
@@ -9,6 +9,8 @@
   to_string.c
   dynamic_array.h
   dynamic_array.c
+  linked_list.h
+  linked_list.c
   callback.h
   callback.c
   thread.h

=== modified file 'tests/dynamic_array.c'
--- tests/dynamic_array.c	2015-10-25 19:56:39 +0000
+++ tests/dynamic_array.c	2016-01-25 21:52:28 +0000
@@ -4,7 +4,8 @@
 #include <stdint.h>
 #include <time.h>
 
-void for_each_print (SDynamicArray * self, sint item, sint * itt) {
+void
+for_each_print_arr (SDynamicArray * self, sint item, sint * itt) {
   s_print ("The number is: %d on iteration: %d\n", item, (*itt));
   (*itt)++;
 }
@@ -50,7 +51,7 @@
 
   sint itt = 0;
   s_print ("Printing array using a for-each function.\n");
-  s_dynamic_array_for_each (array, (ForEachFunc)for_each_print, &itt);
+  s_dynamic_array_for_each (array, FOREACHFUNC (for_each_print_arr), &itt);
 
   s_dynamic_array_free (array, FALSE);
 

=== modified file 'tests/error.c'
--- tests/error.c	2015-10-26 18:59:48 +0000
+++ tests/error.c	2016-01-25 21:52:28 +0000
@@ -4,7 +4,7 @@
 
 void
 _internal_print_error (SDynamicArray * arr, schar * str, spointer data) {
-    s_print ("YO!");
+  s_print ("YO!");
   s_print ("(Error Test): %s\n", str);
   s_print ("YO!");
 }
@@ -15,11 +15,9 @@
   SDynamicArray * arr = NULL;
 
   SError * e = NULL;
-  schar * s = NULL;
 
   test_case (s_error_has_error (e) == FALSE, "The error is not set. (NULL)");
 
-  schar * expected_string = NULL;
 
   e = s_error_new ();
   test_case (e != NULL, "Error is not NULL");

=== added file 'tests/linked_list.c'
--- tests/linked_list.c	1970-01-01 00:00:00 +0000
+++ tests/linked_list.c	2016-01-25 21:52:28 +0000
@@ -0,0 +1,62 @@
+#include "SimpleTypeSystem.h"
+#include "test_macros.h"
+#include <stdlib.h>
+#include <stdint.h>
+#include <time.h>
+
+void
+for_each_print_lst (SLinkedList * self, sint item, sint * itt) {
+  s_print ("The number is: %d on iteration: %d\n", item, (*itt));
+  (*itt)++;
+}
+
+int test_linked_list (void) {
+  setup_unit ();
+  
+  SLinkedList * list = NULL;
+  list = s_linked_list_new (NULL);
+  
+  test_case (list != NULL, "Linked list not null");
+  
+  s_print ("Adding a random number to the linked list (bettween 0 and 20).\n");
+  
+  srand(time(NULL));
+  
+  sint r_p = rand () % 20;
+  
+  s_linked_list_append (list, (spointer)(intptr_t) r_p);
+  
+  test_case (s_linked_list_len (list) == 1, "The reported length of the linked"
+                                            " list is 1.");
+  
+  test_case (s_linked_list_get_next (list) == NULL, "There are no next items in the"
+                                             " linked list.");
+  
+  test_case (s_linked_list_get_prev (list) == NULL, "There are no previous items in"
+                                             " the linked list.");
+  
+  test_case (s_linked_list_get_current (list) != NULL, "The current item exists.");
+  
+  test_case ((intptr_t) s_linked_list_get_current (list) == r_p, "The value"
+                                 "addad was the same as the one retrieved.");
+  
+  s_print ("Removing current item in preperation for next test.\n");
+  
+  s_linked_list_remove_current (list, FALSE);
+  
+  s_print ("Item removed");
+  
+  test_case (s_linked_list_len (list) == 0, "The reported list length is 0");
+  
+  s_print ("Filling list with twenty items (0, 1, ... 18, 19)\n");
+  
+  for (int i = 0; i < 20; i++) {
+    s_linked_list_append (list, (spointer)(intptr_t) i);
+  }
+  
+  s_linked_list_free (list, FALSE);
+  
+  s_print ("Freed stuffs.\n");
+  
+  end_unit ();
+}

=== added file 'tests/linked_list.h'
--- tests/linked_list.h	1970-01-01 00:00:00 +0000
+++ tests/linked_list.h	2016-01-25 21:52:28 +0000
@@ -0,0 +1,4 @@
+#ifndef __H_TEST_LINKED_LIST__
+#define __H_TEST_LINKED_LIST__
+int test_linked_list (void);
+#endif

=== modified file 'tests/main.c'
--- tests/main.c	2015-10-28 14:45:22 +0000
+++ tests/main.c	2016-01-25 21:52:28 +0000
@@ -10,17 +10,19 @@
 #include "error.h"
 #include "dynamic_array.h"
 #include "callback.h"
-
+#include "linked_list.h"
+#include "thread.h"
 
 int main  (int argc, char ** argv, char ** argp) {
   setup_suite ("SSTS");
-
+  
   test_unit (test_refcount, "Refcount");
   test_unit (test_to_string, "To String");
   test_unit (test_error, "Error");
   test_unit (test_dynamic_array, "Dynamic Array");
-  test_unit (test_callback, "Callback");
-  test_unit (test_thread, "Threading");
+  test_unit (test_linked_list, "Linked List");
+  //test_unit (test_callback, "Callback");
+  //test_unit (test_thread, "Threading");
 
   end_suite ();
 }

